# RoadMap

## 2025 Q4

- Finish core modules: Experiment, Model, Checkpoint, Metric, Log
- Add GraphQL API support
- Add dashboard for experiment tracking and visualization

## 2026 Q1

- Cost tracking for Experiments
- Playground for quick prototyping
- Prompt management system with versioning
- Prompt optimization tools integration, like DSPy

## More

- Model leaderboard for comparing different models
- Evaluation module for application performance assessment
- Dataset management and versioning
- Security and compliance features
- Chatbot framework for building conversational agents
- MCP tools integration
